@@ -1,6 +1,14 @@
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
 \echo Use "CREATE EXTENSION pgpool_recovery" to load this file. \quit
 
+CREATE FUNCTION pgpool_recovery(IN script_name text,
+	   IN remote_host text,
+	   IN remote_data_directory text,
+	   IN remote_port text)
+RETURNS bool
+AS 'MODULE_PATHNAME', 'pgpool_recovery'
+LANGUAGE C STRICT;
+
 CREATE FUNCTION pgpool_recovery(IN script_name text,
 	   IN remote_host text,
 	   IN remote_data_directory text)
