@@ -16,7 +16,7 @@ MODE=install
 PG_INSTALL_DIR=/usr/local/pgsql/bin
 PGPOOL_PATH=/usr/local
 JDBC_DRIVER=/usr/local/pgsql/share/postgresql-9.2-1003.jdbc4.jar
-log=$dir/log
+export log=$dir/log
 fail=0
 ok=0
 timeout=0
@@ -35,8 +35,8 @@ function install_pgpool
 	echo "creating pgpool-II temporary installation ..."
         PGPOOL_PATH=$dir/temp/installed
 
-        test -d $log || mkdir $log
-
+	test -d $log || mkdir $log
+        
 	make install -C $dir/../../ -e prefix=${PGPOOL_PATH} >& $log/regression.log 2>&1
 
 	if [ $? != 0 ];then
@@ -91,9 +91,9 @@ function export_env_vars
 
 	PGPOOLLIB=${PGPOOL_INSTALL_DIR}/lib
 	if [ -z "$LD_LIBRARY_PATH" ];then
-	    export LD_LIBRARY_PATH=${PGPOOLLIB}:${PGLIB}
+	    export LD_LIBRARY_PATH=$PGPOOLLIB
 	else
-	    export LD_LIBRARY_PATH=${PGPOOLLIB}:${PGLIB}:${LD_LIBRARY_PATH}
+	    export LD_LIBRARY_PATH=${PGPOOLLIB}:${LD_LIBRARY_PATH}
 	fi
 
 	export TESTLIBS=$dir/libs.sh
@@ -168,7 +168,6 @@ fi
 verify_pginstallation
 export_env_vars
 print_info
-source $TESTLIBS
 
 #Start executing tests
 rm -fr $log
@@ -186,7 +185,6 @@ for i in $dirs
 do
 	cd $i
 	echo -n "testing $i..."
-	clean_all
 	timeout $TIMEOUT ./test.sh > $log/$i 2>&1
 	rtn=$?
 	if [ $rtn = 0 ];then
